## How to install

The use of `pipx` is recommended for installing GRAMEP:

<!-- termynal -->

```
$ pipx install gramep
```

Although this is only a recommendation, you can also install the project with the manager of your choice. For example, `pip`:

<!-- termynal -->

```
$ pip install gramep
```
